package org.jboss.qa.brms.multithreaded;

import java.io.StringReader;

import org.drools.KnowledgeBase;
import org.drools.KnowledgeBaseConfiguration;
import org.drools.KnowledgeBaseFactory;
import org.drools.builder.KnowledgeBuilder;
import org.drools.builder.KnowledgeBuilderFactory;
import org.drools.builder.ResourceType;
import org.drools.conf.MaxThreadsOption;
import org.drools.conf.MultithreadEvaluationOption;
import org.drools.io.ResourceFactory;
import org.drools.runtime.StatefulKnowledgeSession;

public class NonStopTest {
    private static final String drl = "package org.jboss.qa.brms.multithreaded\n" +
            "rule hello\n" +
            "    when\n" +
            "    then\n" +
            "        System.out.println(\"Hello world!\");\n" +
            "end";

    public static void main(String[] args) {
        KnowledgeBuilder kbuilder = KnowledgeBuilderFactory.newKnowledgeBuilder();
        kbuilder.add(ResourceFactory.newReaderResource(new StringReader(drl)), ResourceType.DRL);

        if (kbuilder.hasErrors()) {
            throw new RuntimeException(kbuilder.getErrors().toString());
        }

        KnowledgeBaseConfiguration kbconf = KnowledgeBaseFactory.newKnowledgeBaseConfiguration();
        kbconf.setOption(MultithreadEvaluationOption.YES);
        kbconf.setOption(MaxThreadsOption.get(4));

        KnowledgeBase kbase = KnowledgeBaseFactory.newKnowledgeBase(kbconf);
        kbase.addKnowledgePackages(kbuilder.getKnowledgePackages());

        StatefulKnowledgeSession ksession = kbase.newStatefulKnowledgeSession();

        ksession.fireAllRules();

        System.out.println("I'm finished... ");

        ksession.dispose();
    }

}
